// clang-format off

#define PREFIX "user/examples/yamlcpp/"

ksNew (10,
       keyNew (PREFIX "bloc/party/little", KEY_VALUE, "thoughts", KEY_END),
       keyNew (PREFIX "bloc/party/silent", KEY_VALUE, "alarm", KEY_END),
       KS_END)
